@@ -42,7 +42,7 @@
 
 class KPicoSim : public TDEMainWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 	public:
 	    KPicoSim();
