@@ -48,7 +48,7 @@ KPortView::KPortView( CPicoBlaze *cpu, TQWidget *parent, const char *name)
 	m_editID->setText( "0" ) ;
 	m_editID->setFixedSize( 30, 20 ) ;
 	m_editID->move( 2, 22 );
-	connect( m_editID, TQT_SIGNAL( textChanged( const TQString &) ), this, TQT_SLOT( setID( const TQString &) ) ) ;
+	connect( m_editID, TQ_SIGNAL( textChanged( const TQString &) ), this, TQ_SLOT( setID( const TQString &) ) ) ;
 	
 	int i ;
 	for ( i = 0 ; i < 8 ; i++ ) {
@@ -65,10 +65,10 @@ KPortView::KPortView( CPicoBlaze *cpu, TQWidget *parent, const char *name)
 	m_port = new KPort( 0 ) ;
 	m_cpu->addPort( m_port ) ;
 	
-	connect( m_port, TQT_SIGNAL( read() ), this, TQT_SLOT( read() ) ) ;
-	connect( m_port, TQT_SIGNAL( write(unsigned char) ), this, TQT_SLOT( write(unsigned char) ) ) ;
-	connect( m_readable, TQT_SIGNAL( toggled(bool) ), this, TQT_SLOT( readableToggled(bool) ) ) ;
-	connect( m_writeable, TQT_SIGNAL( toggled(bool) ), this, TQT_SLOT( writeableToggled(bool) ) ) ;
+	connect( m_port, TQ_SIGNAL( read() ), this, TQ_SLOT( read() ) ) ;
+	connect( m_port, TQ_SIGNAL( write(unsigned char) ), this, TQ_SLOT( write(unsigned char) ) ) ;
+	connect( m_readable, TQ_SIGNAL( toggled(bool) ), this, TQ_SLOT( readableToggled(bool) ) ) ;
+	connect( m_writeable, TQ_SIGNAL( toggled(bool) ), this, TQ_SLOT( writeableToggled(bool) ) ) ;
 	
 	setWidget( widget ) ;
 	setCloseMode( Always ) ;
